@@ -529,7 +529,7 @@ english = {'present': (
                      'no chance',
                      '100%',
                      'guaranteed to'],
-               ['definitely','definetly',#missspelling
+               ['definitely','definetly',"definately",#missspelling
                 'definite',
                 'certainly',
                 'certain',
@@ -650,9 +650,10 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'leuk vindt','leuk vind','leuk vinden',
                      'ze halen het',
                      'val om','stort in','valt om',
-                     'storten in','storten inen',
+                     'storten in','storten inen',"storrte in",
                      'kom aan','komt aan','komen aan','knap op','kom ik',
                      'knapt op','knappen op',
+                     "klim op","klimt op","klimmen op",
                      'uit eet',
                      'ze halen het','zij halen het','haal het','haalt het','halen het',
                      'kom op','komt op','komen op',
@@ -664,11 +665,19 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'schrijf in','schrijft in','schrijven in',
                      'loop af','loopt af','lopen af',
                      'geef uit','geeft uit','geven uit',
-                     'zich voel','zich voelt','zich voelen'
+                     'zich voel','zich voelt','zich voelen',
+                     "duik in","duikt in","duiken in",
+                     "zak in", "zakt in","zakken in",
+                     "veel aan in", #much of it trans: "gain"
+                     "val om","valt om","vallen om","volt om"#typo
                      ],
 
                     ['.is',#typo
                      'ishet',#typo
+                     "broeris",#typo "brother is"
+                     "aankomt",
+                     "aankom",
+                     "aankomen",
                      'aanvragen',
                      'aflopen',
                      'afstuderen',
@@ -699,6 +708,8 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'breek',
                      'breekt',
                      'breken',
+                     "bezit",
+                     "bezitten",
                      'crashen',
                      'crashed',#typo
                      'crahst',#typo 
@@ -721,6 +732,9 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'duur',
                      'duurt',
                      'duuren',
+                     "duik",
+                     "duikt",
+                     "duiken",
                      'eindig',
                      'eindigd',#typo
                      'eindigt',
@@ -744,6 +758,7 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'helpen',
                      'inschrijven',
                      'instorten',
+                     "instort",
                      'is',
                      'is.',#typo
                      'kijk',
@@ -762,6 +777,12 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'krijg',
                      'krijgen',
                      'krijgt',
+                     "klim",
+                     "klimt",
+                     "klimmen",
+                     "leef",
+                     "leeft",
+                     "leven",
                      'loopt',
                      'lopen',
                      'loop',
@@ -775,15 +796,16 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'nemen',
                      'neem',
                      'neemt',
-                     'omvalt',
-                     'omval',
-                     'omvalen',
+                     "onvallen","omgevallen",#typo
                      'pas',
                      'past',
                      'passen',
                      'regen',
                      'regenen',
                      'regent',
+                     "regel",
+                     "regelt",
+                     "regelen",
                      'reis',
                      'reist',
                      'reizen',
@@ -836,6 +858,9 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'val',
                      'vallen',
                      'valt',
+                     "verblijf",
+                     "verblijft",
+                     "verblijven",
                      'verdedig',
                      'verdedigt',
                      'verdedigen',
@@ -890,11 +915,12 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'verval',
                      'vervalt',
                      'vervallen',
+                     "waard",#resp. appear to use waard without a verb sometimes
                      'weetblijft',#typo
                      'werk',
                      'werken',
                      'werkt',
-                     'wetkt',#typo
+                     'wetkt',"werkit",#typos
                      'win',
                      'winnen',
                      'wint',
@@ -912,6 +938,9 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'zijn',
                      'zinnen',
                      'zit',
+                     "zak",
+                     "zakt",
+                     "zakken",
                      'zitten',
                      'zwel',
                      'zwellen',
@@ -943,6 +972,7 @@ dutch = {'present':(['is het','vallen om','storten in',
                         ['ingestort',
                          'omgevald',
                          'aangekomen',
+                         "bezeten",
                          'opgeknapt',
                          'uitgeeët',
                          'opgekomen',
@@ -950,6 +980,8 @@ dutch = {'present':(['is het','vallen om','storten in',
                          'afgestudeerd',
                          'aangevraagd',
                          'ingeschreven',
+                         "ingezakt",
+                         "gezakt",
                          'afgeloopt',
                          'uitgeven',
                          'geweest',
@@ -963,10 +995,12 @@ dutch = {'present':(['is het','vallen om','storten in',
                          'gebroken',
                          'gegreven',
                          'gecrashd',
+                         "gegaan",
                          'gedaald',
                          'gedankt',
                          'gedaan',
                          'gedood',
+                         "gedoken",
                          'geduurd',
                          'geëindigd',
                          'gegeten',
@@ -974,8 +1008,12 @@ dutch = {'present':(['is het','vallen om','storten in',
                          'gehaald',
                          'geheeld',
                          'geholpen',
+                         "geklommen",
+                         "opgeklimd",
                          'gelopen',
+                         "geleefd",
                          'ingeschreven',
+                         "ingeduikt",
                          'gekeken',
                          'geknapt',
                          'gekomen',
@@ -987,6 +1025,7 @@ dutch = {'present':(['is het','vallen om','storten in',
                          'genomen',
                          'gepast',
                          'geregend',
+                         "geregeld",
                          'gereisd',
                          'geresideerd',
                          'gereden',
@@ -1003,6 +1042,7 @@ dutch = {'present':(['is het','vallen om','storten in',
                          'gestormd',
                          'gespeeld',
                          'gevallen',
+                         "verbleven",
                          'verdedigd',
                          'verdubbeld',
                          'vervoegd',
@@ -1034,6 +1074,8 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'aamden na',
                      'contact opneemde',
                      'contact opneemden',
+                     "duikte in",
+                     "duikten in",
                      'eette uit',
                      'eetten uit',
                      'gaf uit',
@@ -1048,6 +1090,8 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'knapten op',
                      'kwam aan',
                      'kwamen aan',
+                     "klimde op",
+                     "klimden op",
                      'leuk vond',
                      'leuk vonden',
                      'loopte af',
@@ -1060,6 +1104,8 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'studeerden af',
                      'vaalde om',
                      'vaalden om',
+                     "valde om",
+                     "valden om",
                      'vraagde aan',
                      'vraagden aan',
                      'vroeg aan',
@@ -1072,11 +1118,15 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'zich voelden',                     
                      'zwelde op',
                      'zwelden op',
+                     "zakte in",
+                     "zakten in"                     
                      ],
                     ['was',
                      'waren',
                      'accepteerde',
-                     'accepteerden',                     
+                     'accepteerden',      
+                     "bezat",
+                     "bezaten",
                      'bedankte',
                      'bedankten',
                      'begoonde',
@@ -1086,6 +1136,8 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'bekeek',
                      'bekeeken',
                      'beldde',
+                     "belde",
+                     "belden",
                      'beldden',
                      'bereikte',
                      'bereikten',
@@ -1104,6 +1156,8 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'doodden',    
                      'deed',
                      'deden',
+                     "dook",
+                     "dooken",
                      'duurde',
                      'duurden',
                      'eindigde',
@@ -1114,6 +1168,8 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'explodeerden',
                      'gaf',
                      'gaven',
+                     "ging",
+                     "gingen",
                      'haalde',
                      'haalden',
                      'had',
@@ -1122,7 +1178,10 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'heelden',
                      'hielp',
                      'hielpen',
+                     "klom",
+                     "klommen",
                      'keek',
+                     "kelderd",
                      'keken',
                      'knapte',
                      'knapten',
@@ -1132,6 +1191,8 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'kochten',
                      'kreeg',
                      'kregen',
+                     "leefde",
+                     "leefden",
                      'liette',#lietten same as present
                      'liep',
                      'liepen',
@@ -1139,6 +1200,8 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'maakten',
                      'paste',
                      'pasten',
+                     "regelde",
+                     "regelden",
                      'reegde',
                      'reegden',
                      'reisde',
@@ -1207,6 +1270,8 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'volgden',
                      'vraagde',
                      'vraagden',
+                     "verbleef",
+                     "verbleven",
                      'werkte',
                      'werkten',
                      'won',
@@ -1215,6 +1280,8 @@ dutch = {'present':(['is het','vallen om','storten in',
                      'woonden',
                      'werd',
                      'werden',
+                     "zakte",
+                     "zakten",
                      'zag',
                      'zagen',
                      'zei',
@@ -1230,7 +1297,7 @@ dutch = {'present':(['is het','vallen om','storten in',
           'future':(['staat op'],#about to
                    ['ga',
                     'gaat',
-                    'gat',#common typo
+                    'gat',"gaar",#common typos
                     'gaan',
                     'zal', 
                     'zullen',
@@ -1357,7 +1424,9 @@ dutch = {'present':(['is het','vallen om','storten in',
                         'volgens mijn',
                         'houden voor',
                         'niet weten',
-                        'neit weet'],
+                        'neit weet',
+                        'weet niet',
+                        "weten niet"],
                         ['denk',
                          'denken',
                          'denkt',
@@ -1424,8 +1493,8 @@ dutch = {'present':(['is het','vallen om','storten in',
                      ['ga',
                       'gaat',
                       'gaan',
-                      'gat',#typo
-                      'gaanverliezen']#typo
+                      'gat',"gaar",'gaanverliezen'
+                      ]#typo
                      ),
     'verb_des_int':(['het lijkt zo goed'],
                    ['wil',
@@ -1466,7 +1535,11 @@ german = {'present':(['nutze ab',
                       'bricht zusammen',
                       'brechen zusammen',
                       'brecht zusammen'],
-                     ['bin',
+                     ['arbeite',
+                      'arbeitest',
+                      'arbeitet',
+                      'arbeiten',
+                      'bin',
                       'bist', 
                       'ist', 
                       'sind',#typo
@@ -1496,10 +1569,6 @@ german = {'present':(['nutze ab',
                       'hat',
                       'haben',
                       'habt',
-                      'arbeite',
-                      'arbeitest',
-                      'arbeitet',
-                      'arbeiten',
                       'fühle',
                       'fühlst',
                       'fühlt',
@@ -1525,6 +1594,7 @@ german = {'present':(['nutze ab',
                       'reise',
                       'reist',
                       'reisen',
+                      "rijs",#typo
                       'ruft',
                       'rufst',
                       'rufe',
